from prisma import *

def execute_search():
  print('PENDING')
  return {}

def execute_create():
  print('PENDING')
  return {}

def execute_update():
  print('PENDING')
  return {}

def execute_delete():
  print('PENDING')
  return {}
